/*
  LiquidCrystal Library - Hello World

 Demonstrates the use a 16x2 LCD display.  The LiquidCrystal
 library works with all LCD displays that are compatible with the
 Hitachi HD44780 driver. There are many of them out there, and you
 can usually tell them by the 16-pin interface.

 This sketch display a Rain Storm Animation and an Anemometer animation
 on (Row0, Col0), --- (Row1,Col1)
 
 More info on custom icons at:
 https://www.engineersgarage.com/arduino/making-custom-characters-on-lcd-using-arduino/
 A useful tool to generate code for your visualisation is
 https://maxpromer.github.io/LCD-Character-Creator/
 
  The circuit:
 * LCD RS pin to digital pin 12
 * LCD Enable pin to digital pin 11
 * LCD D4 pin to digital pin 5
 * LCD D5 pin to digital pin 4
 * LCD D6 pin to digital pin 3
 * LCD D7 pin to digital pin 2
 * LCD R/W pin to ground
 * LCD VSS pin to ground
 * LCD VCC pin to 5V
 * 10K resistor:
 * ends to +5V and ground
 * wiper to LCD VO pin (pin 3)



 This example code is in the public domain.

 http://www.arduino.cc/en/Tutorial/LiquidCrystal
 */

// include the library code:
#include <LiquidCrystal.h>

//defining rain Animated ICON

//First Frame (Rain 1)
byte rainChar1[] = {
  B01110,
  B11110,
  B11111,
  B01101,
  B00001,
  B10010,
  B10010,
  B00100
};

byte rainChar2[] = {
  B00100,
  B01001,
  B01001,
  B10010,
  B10010,
  B00100,
  B00100,
  B01001
};

byte rainChar3[] = {
  B01110,
  B01111,
  B11111,
  B11111,
  B11110,
  B11001,
  B01001,
  B10010
};

byte rainChar4[] = {
  B10010,
  B00100,
  B00100,
  B01001,
  B01001,
  B10010,
  B10010,
  B00100
};


//Second Frame (Rain 2)
byte rainChar5[] = {
  B01110,
  B11110,
  B11111,
  B01100,
  B10001,
  B00010,
  B10010,
  B00100
};

byte rainChar6[] = {
  B00100,
  B01000,
  B01001,
  B10010,
  B10010,
  B00100,
  B00100,
  B01001
};

byte rainChar7[] = {
  B01110,
  B01111,
  B11111,
  B11111,
  B11110,
  B11000,
  B01001,
  B10010
};

byte rainChar8[] = {
  B10010,
  B00000,
  B00100,
  B00100,
  B01001,
  B01001,
  B10010,
  B10010
};
  

//Third Frame (Wind1)
byte windChar1[] = {
  B00000,
  B00000,
  B00000,
  B00011,
  B00111,
  B00111,
  B00111,
  B00011
};

byte windChar2[] = {
  B11111,
  B11111,
  B01110,
  B00000,
  B00000,
  B00000,
  B00000,
  B00000
};

byte windChar3[] = {
  B00000,
  B00000,
  B00000,
  B00000,
  B00000,
  B01110,
  B11111,
  B11111
};

byte windChar4[] = {
  B11000,
  B11100,
  B11100,
  B11100,
  B11000,
  B00000,
  B00000,
  B00000,
};


// Fourth Frame (Wind 2)

byte windChar5[] = {
  B00000,
  B00000,
  B00000,
  B00000,
  B01000,
  B11100,
  B11110,
  B01111
};

byte windChar6[] = {
  B00001,
  B00011,
  B00111,
  B01111,
  B00110,
  B00000,
  B00000,
  B00000
};

byte windChar7[] = {
  B00000,
  B00000,
  B00000,
  B01100,
  B11110,
  B11100,
  B11000,
  B10000
};

byte windChar8[] = {
  B11110,
  B01111,
  B00111,
  B00010,
  B00000,
  B00000,
  B00000,
  B00000
};

// initialize the LCD library with the numbers of the interface pins
//LiquidCrystal lcd(12, 11, 5, 4, 3, 2); //Arduino
LiquidCrystal lcd(22,23,5,18,19,21); //ESP32


void setup() {
  // set up the LCD's number of columns and rows:
  lcd.begin(16, 2);
  // Print a message to the LCD.
  lcd.print("ANIMATED");
  lcd.setCursor(0,1);
  lcd.print("WEATHER ICONS");
  /*In some sketches the character is generated in setup(). The
  Hitachi HD44780 driver can hower only accomodate 8 characters in memory and 
  I therefore create them dynamicly in the loop()
  */
}

void loop() {
  //Creating the 2 rain frames
   for (int i = 0; i <= 5; i++) {
       lcd.clear();
      lcd.createChar(1 , rainChar1); //Numbering should start at 1, not 0
      lcd.createChar(2 , rainChar2);
      lcd.createChar(3 , rainChar3);
      lcd.createChar(4 , rainChar4);
      lcd.createChar(5 , rainChar5);
      lcd.createChar(6 , rainChar6);
      lcd.createChar(7 , rainChar7);
      lcd.createChar(8 , rainChar8);
      lcd.setCursor(0,0);
      lcd.write(1);
      lcd.setCursor(0,1);
      lcd.write(2);
      lcd.setCursor(1,0);
      lcd.write(3);
      lcd.setCursor(1,1);
      lcd.write(4);
      lcd.setCursor(3,0);
      lcd.print("Rain");
      lcd.setCursor(3,3);
      lcd.print("Animation");
      delay (900);
      lcd.clear();
      lcd.setCursor(0,0);
      lcd.write(5);
      lcd.setCursor(0,1);
      lcd.write(6);
      lcd.setCursor(1,0);
      lcd.write(7);
      lcd.setCursor(1,1);
      lcd.write(8);
      lcd.setCursor(3,0);
      lcd.print("Rain");
      lcd.setCursor(3,3);
      lcd.print("Animation");
      delay (900);
  }
   //Creating the two wind (anemometer) frames
  for (int i = 0; i <= 30; i++) {
      lcd.clear();
      lcd.createChar(1 , windChar1); //Numbering should start at 1, not 0
      lcd.createChar(2 , windChar2);
    lcd.createChar(3 , windChar3);
      lcd.createChar(4 , windChar4);
      lcd.createChar(5 , windChar5);
      lcd.createChar(6 , windChar6);
      lcd.createChar(7 , windChar7);
      lcd.createChar(8 , windChar8);
      lcd.setCursor(0,0);
      lcd.write(1);
      lcd.setCursor(0,1);
      lcd.write(2);
      lcd.setCursor(1,0);
      lcd.write(3);
      lcd.setCursor(1,1);
      lcd.write(4);
      lcd.setCursor(3,0);
      lcd.print("Anemometer");
      lcd.setCursor(3,3);
      lcd.print("Animation");
      delay (200); 
      lcd.clear();
      lcd.setCursor(0,0);
      lcd.write(5);
      lcd.setCursor(0,1);
      lcd.write(6);
      lcd.setCursor(1,0);
      lcd.write(7);
         lcd.setCursor(1,1);
      lcd.write(8);
      lcd.setCursor(3,0);
      lcd.print("Anemometer");
      lcd.setCursor(3,3);
      lcd.print("Animation");
      delay (200);

  }
}
